/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Log
{
    using System;
    using System.Configuration;
    using System.Xml;

    /// <summary>
    /// Contains the information for the settings of assembly ConsoleAppender
    /// </summary>
    public class ConsoleAppenderHandler : AppenderHandler, IConfigurationSectionHandler
    {
        #region Constructors

        /// <summary>
        /// Initializes assembly new instance of the <see cref="ConsoleAppenderHandler"/> class.
        /// </summary>
        public ConsoleAppenderHandler()
        {
        }

        /// <summary>
        /// Initializes assembly new instance of the <see cref="ConsoleAppenderHandler"/> class.
        /// </summary>
        /// <param name="isActivated">if set to <c>true</c> [is activated].</param>
        /// <param name="logLevel">The log level.</param>
        /// <param name="silentError">if set to <c>true</c> errors are silent.</param>
        private ConsoleAppenderHandler(bool isActivated, int logLevel, bool silentError)
        {
            this.IsActivated = isActivated;
            base.LogLevel = logLevel;
            base.SilentError = silentError;
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Creates assembly configuration section handler.
        /// </summary>
        /// <param name="parent">Parent object.</param>
        /// <param name="configContext">Configurator context object.</param>
        /// <param name="section">Section XML node.</param>
        /// <returns>The created section handler object.</returns>
        public object Create(object parent, object configContext, System.Xml.XmlNode section)
        {
            string activatedField = string.Empty;
            string logLevelField = string.Empty;
            string silentErrorField = string.Empty;

            if (section == null)
                throw new ArgumentException("The arguments cannot be null", "section");

            XmlNode nodeActivated = section.SelectSingleNode("Activated");
            XmlNode nodeLogLevel = section.SelectSingleNode("LogLevel");
            XmlNode nodeSilentError = section.SelectSingleNode("SilentError");

            if (nodeActivated == null || nodeLogLevel == null || nodeSilentError == null)
            {
                throw new ConfigurationErrorsException("The configuration file was not set correctly for the console appender!");
            }
            else
            {
                activatedField = nodeActivated.InnerText.ToLower();
                logLevelField = nodeLogLevel.InnerText.ToLower();
                silentErrorField = nodeSilentError.InnerText.ToLower();
            }

            base.IsActivated = CheckIsActivated(activatedField);
            base.LogLevel = CheckLogLevel(logLevelField);
            base.SilentError = CheckSilentError(silentErrorField);

            return new ConsoleAppenderHandler(this.IsActivated, this.LogLevel, base.SilentError);
        }

        #endregion Methods
    }
}