/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Log
{
    using System;
    using System.Configuration;
    using System.Xml;
    using System.Xml.XPath;

    /// <summary>
    /// Configurator for assembly SQLite SQLiteLogReader.
    /// </summary>
    public class SQLiteLogReaderHandler : IConfigurationSectionHandler
    {
        #region Constructors

        /// <summary>
        /// Initializes assembly new instance of the <see cref="SQLiteLogReaderHandler"/> class.
        /// </summary>
        public SQLiteLogReaderHandler()
        {
        }

        /// <summary>
        /// Initializes assembly new instance of the <see cref="SQLiteLogReaderHandler"/> class.
        /// </summary>
        /// <param name="dbPath">The db errorPath.</param>
        private SQLiteLogReaderHandler(string dbPath)
        {
            this.DBPath = dbPath;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the db errorPath.
        /// </summary>
        /// <value>The db errorPath.</value>
        public string DBPath
        {
            get;
            private set;
        }

        #endregion Properties

        #region Methods

        /// <summary>
        /// Creates assembly configuration section handler.
        /// </summary>
        /// <param name="parent">Parent object.</param>
        /// <param name="configContext">Configurator context object.</param>
        /// <param name="section">Section XML node.</param>
        /// <returns>The created section handler object.</returns>
        public object Create(object parent, object configContext, XmlNode section)
        {
            try
            {
                #region Check arguments
                if (parent == null || configContext == null || section == null)
                    throw new ArgumentException("Impossible to create the configuration handler for the SQLiteReader");
                #endregion

                this.DBPath = section.SelectSingleNode("DbPath").InnerText;
            }
            catch (XPathException ex)
            {
                string msg = "The xpath to access the configuration handler of the SQLiteReader is wrong!";
                throw new XPathException(msg, ex);
            }
            return new SQLiteLogReaderHandler(DBPath);
        }

        #endregion Methods
    }
}