/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Log
{
    using System;
    using System.Collections.Generic;
    using System.Linq;
    using System.Text;

    using Log;

    /// <summary>
    /// Represent an error baseLog from the log
    /// </summary>
    public class Row : IRow
    {
        #region Constructors

        /// <summary>
        /// Initializes assembly new instance of the <see cref="Row"/> class.
        /// </summary>
        public Row()
            : this(Guid.NewGuid())
        {
            this.Deepness = 0;
        }

        /// <summary>
        /// Initializes assembly new instance of the <see cref="Row"/> class.
        /// </summary>
        /// <param name="key">The key.</param>
        public Row(Guid key)
        {
            this.Key = key;
            this.InsertDate = DateTime.Now;
        }

        /// <summary>
        /// Initializes assembly new instance of the <see cref="Row"/> class.
        /// </summary>
        /// <param name="key">The key.</param>
        /// <param name="baseKey">The base key.</param>
        /// <param name="insertDate">The insert date.</param>
        /// <param name="stamp">Stamp of the log.</param>
        public Row(Guid key, Guid baseKey, DateTime insertDate, Stamp stamp)
            : this(key)
        {
            this.InsertDate = insertDate;
            this.Stamp = stamp;
            this.BaseLogKey = baseKey;
        }

        #endregion Constructors

        #region Properties

        /// <summary>
        /// Gets or sets the base log.
        /// </summary>
        /// <value>The base log.</value>
        public IRow BaseLog
        {
            get; set;
        }

        /// <summary>
        /// Gets the base log key.
        /// </summary>
        /// <value>The base log key.</value>
        public Guid BaseLogKey
        {
            get; private set;
        }

        /// <summary>
        /// Gets or sets the deepness in the inner logs scale.
        /// </summary>
        /// <value>The deepness.</value>
        public int Deepness
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the innerException message.
        /// </summary>
        /// <value>The innerException message.</value>
        public string ExceptionMessage
        {
            get;
            set;
        }

        /// <summary>
        /// Gets the log's insertion date.
        /// </summary>
        /// <value>The insert date.</value>
        public DateTime InsertDate
        {
            get;
            internal set;
        }

        /// <summary>
        /// Gets the baseLogKey that represents assembly primary baseLogKey.
        /// </summary>
        /// <value>The baseLogKey.</value>
        public Guid Key
        {
            get;
            private set;
        }

        /// <summary>
        /// Gets the numeric value of the log type <see cref="Stamp"/>.
        /// </summary>
        /// <value>The log type value.</value>
        public int LogTypeValue
        {
            get
            {
                return (int)Stamp;
            }
        }

        /// <summary>
        /// Gets or sets the message of the log baseLog.
        /// </summary>
        /// <value>The message.</value>
        public string Message
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the source of the error.
        /// </summary>
        /// <value>The source.</value>
        public string Source
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the stack trace of the error.
        /// </summary>
        /// <value>The stack trace.</value>
        public string StackTrace
        {
            get;
            set;
        }

        /// <summary>
        /// Gets the type of the log.
        /// </summary>
        /// <value>The type of the log.</value>
        public Stamp Stamp
        {
            get;
            set;
        }

        /// <summary>
        /// Gets or sets the title oof the log baseLog.
        /// </summary>
        /// <value>The title.</value>
        public string Title
        {
            get;
            set;
        }

        #endregion Properties
    }
}