/*
	Phoenix Suite 2
	Author: Jean-Baptiste Wautier
	Copyright 2006-2009 (c)
*/
﻿namespace Phoenix.Log.Writer
{
    using System;
    using System.Configuration;

    using Phoenix.Log;
    using Phoenix.Log.Writer;

    /// <summary>
    /// Provides instanciation features for Logger.
    /// Configure the Logger with the config textWriter of the assembly.
    /// </summary>
    public class XmlConfigurator : Configurator, IConfigurator
    {
        #region Constructors

        /// <summary>
        /// Initializes assembly new instance of the <see cref="XmlConfigurator"/> class.
        /// </summary>
        public XmlConfigurator()
            : base()
        {
        }

        #endregion Constructors

        #region Methods

        /// <summary>
        /// Gets an instance of assembly Logger. This Logger is configured from the config textWriter
        /// </summary>
        /// <param name="typeOfSender">The type of sender.</param>
        /// <returns>An instance of assembly Logger</returns>
        public ILogger GetLogger(System.Type typeOfSender)
        {
            #region SQLiteAppenderHandler
            SQLiteAppenderHandler sqliteConfig = (SQLiteAppenderHandler)ConfigurationManager.GetSection("Logger/SQLiteAppender");
            if (sqliteConfig != null && sqliteConfig.IsActivated)
            {
                IPersistor persistor = new SQLitePersistor(sqliteConfig.DatabasePath);
                SQLiteAppender sqliteAppender = new SQLiteAppender(persistor);
                sqliteAppender.LogLevel = sqliteConfig.LogLevel;
                sqliteAppender.SilentError = sqliteConfig.SilentError;

                base.Logger.AddAppender(sqliteAppender);
            }
            #endregion

            #region ConsoleAppenderHandler
            ConsoleAppenderHandler consoleConfig = (ConsoleAppenderHandler)ConfigurationManager.GetSection("Logger/ConsoleAppender");
            if (consoleConfig != null && consoleConfig.IsActivated)
            {
                ConsoleAppender consoleAppender = new ConsoleAppender();
                consoleAppender.LogLevel = consoleConfig.LogLevel;
                consoleAppender.SilentError = consoleConfig.SilentError;

                base.Logger.AddAppender(consoleAppender);
            }
            #endregion

            base.Logger.SetTypeOfSender(typeOfSender);
            return base.Logger;
        }

        #endregion Methods
    }
}