--SQLite Maestro 9.10.0.1
------------------------------------------
--Host     : localhost
--Database : F:\__Programmation\_Prog\Phoenix 2\Tools\Tools.Translation\Tools.Translation\Translation.db


CREATE TABLE BaseText (
  ID     integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  Value  text
);


CREATE TRIGGER BaseText_CreateDefaultEnglishBeforeInsert
  AFTER INSERT
  ON BaseText
BEGIN
  INSERT INTO Translation (fk_Language, fk_BaseText, Value)
  VALUES (0, NEW.ID, NEW.Value);      
END;


CREATE TRIGGER BaseText_au_fkr_Translation
  AFTER UPDATE OF ID
  ON BaseText
BEGIN
  UPDATE Translation
  SET fk_BaseText = NEW.ID
  WHERE fk_BaseText = OLD.ID;
END;


CREATE TRIGGER BaseText_bd_fkr_Translation
  BEFORE DELETE
  ON BaseText
BEGIN
  DELETE FROM Translation
  WHERE fk_BaseText = OLD.ID;
END;


CREATE TABLE Language (
  ID           integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  Name         varchar(50) UNIQUE,
  Abreviation  varchar(3) UNIQUE,
  isActive     boolean NOT NULL DEFAULT 0
);


CREATE TRIGGER CheckLanguageTranslationCount
  BEFORE UPDATE OF isActive
  ON Language
BEGIN
  UPDATE Language
  SET isActive = 0;
  END;


CREATE TRIGGER Language_au_fkr_Translation
  AFTER UPDATE OF ID
  ON Language
BEGIN
  UPDATE Translation
  SET fk_Language = NEW.ID
  WHERE fk_Language = OLD.ID;
END;


CREATE TRIGGER Language_bd_fkr_Translation
  BEFORE DELETE
  ON Language
BEGIN
  DELETE FROM Translation
  WHERE fk_Language = OLD.ID;
END;


CREATE TABLE Translation (
  ID           integer PRIMARY KEY AUTOINCREMENT NOT NULL,
  fk_Language  integer,
  fk_BaseText  integer,
  Value        text NOT NULL DEFAULT '',
  /* Foreign keys */
  FOREIGN KEY (fk_Language)
    REFERENCES Language(ID), 
  FOREIGN KEY (fk_BaseText)
    REFERENCES BaseText(ID)
);


CREATE TRIGGER Translation_bi_fk_BaseText
  BEFORE INSERT
  ON Translation
BEGIN
  SELECT CASE
    WHEN (SELECT 1 FROM BaseText WHERE BaseText.ID = NEW.fk_BaseText) IS NULL
    THEN RAISE(ABORT, 'INSERT statement conflicted with COLUMN REFERENCE constraint [Translation -> BaseText].')
  END;
END;


CREATE TRIGGER Translation_bi_fk_Language
  BEFORE INSERT
  ON Translation
BEGIN
  SELECT CASE
    WHEN (SELECT 1 FROM Language WHERE Language.ID = NEW.fk_Language) IS NULL
    THEN RAISE(ABORT, 'INSERT statement conflicted with COLUMN REFERENCE constraint [Translation -> Language].')
  END;
END;


CREATE TRIGGER Translation_bu_fk_BaseText
  BEFORE UPDATE OF fk_BaseText
  ON Translation
BEGIN
  SELECT CASE
    WHEN (SELECT 1 FROM BaseText WHERE BaseText.ID = NEW.fk_BaseText) IS NULL
    THEN RAISE(ABORT, 'UPDATE statement conflicted with COLUMN REFERENCE constraint [Translation -> BaseText].')
  END;
END;


CREATE TRIGGER Translation_bu_fk_Language
  BEFORE UPDATE OF fk_Language
  ON Translation
BEGIN
  SELECT CASE
    WHEN (SELECT 1 FROM Language WHERE Language.ID = NEW.fk_Language) IS NULL
    THEN RAISE(ABORT, 'UPDATE statement conflicted with COLUMN REFERENCE constraint [Translation -> Language].')
  END;
END;


--View: Translations

CREATE VIEW Translations
AS
SELECT
  BaseText.Value AS Value,
  Translation.Value AS TranslatedValue
FROM
  BaseText
  LEFT OUTER JOIN Translation ON (BaseText.ID = Translation.fk_BaseText)
  LEFT OUTER JOIN Language ON (Translation.fk_Language = Language.ID)
WHERE
     Language.isActive = 1
  OR Language.isActive IS NULL;
  
/* Data for table BaseText */




/* Data for table Language */
INSERT INTO Language (ID, Name, Abreviation, isActive) VALUES (0, 'English', 'EN', 0);




/* Data for table Translation */



